@@ -18,8 +18,8 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
-#ifndef STRIGI_FIELDPROPERIESDB_H
-#define STRIGI_FIELDPROPERIESDB_H
+#ifndef STRIGI_FIELDPROPERTIESDB_H
+#define STRIGI_FIELDPROPERTIESDB_H
 
 #include <strigi/strigiconfig.h>
 #include "fieldproperties.h"
@@ -48,6 +48,7 @@ public:
     ~FieldPropertiesDb();
 
     const FieldProperties& properties(const std::string& uri) const;
+    const FieldProperties& propertiesByAlias(const std::string& alias) const;
     const std::map<std::string, FieldProperties>& allProperties() const;
 
     const ClassProperties& classes(const std::string& uri) const;
@@ -69,7 +70,7 @@ public:
      * loaded from the .fieldproperties database and not specified in runtime
      * by calling plugins.
      * This call is a stub for those who want to add values for the field,
-     * which is not addded to the central ontology database.
+     * which is not added to the central ontology database.
      * 
      * NOTE: the default type is stringType
      *       and there is no parent by default
