@@ -28,21 +28,24 @@ using namespace std;
 using namespace Strigi;
 
 // AnalyzerFactory
-const string XbmThroughAnalyzerFactory::widthFieldName("http://freedesktop.org/standards/xesam/1.0/core#width");
-const string XbmThroughAnalyzerFactory::heightFieldName("http://freedesktop.org/standards/xesam/1.0/core#height");
-const string XbmThroughAnalyzerFactory::xHotFieldName("cursor.hot_spot.x");
-const string XbmThroughAnalyzerFactory::yHotFieldName("cursor.hot_spot.y");
 
 void
 XbmThroughAnalyzerFactory::registerFields(FieldRegister& reg) {
-    widthField = reg.registerField(widthFieldName,
-        FieldRegister::integerType, 1, 0);
-    heightField = reg.registerField(heightFieldName,
-        FieldRegister::integerType, 1, 0);
-    xHotField = reg.registerField(xHotFieldName,
-        FieldRegister::integerType, 1, 0);
-    yHotField = reg.registerField(yHotFieldName,
-        FieldRegister::integerType, 1, 0);
+    widthField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#width");
+    heightField = reg.registerField(
+        "http://freedesktop.org/standards/xesam/1.0/core#height");
+    xHotField = reg.registerField(
+        "http://strigi.sf.net/ontologies/0.9#hotSpotX");
+    yHotField = reg.registerField(
+        "http://strigi.sf.net/ontologies/0.9#hotSpotY");
+    typeField = reg.typeField;
+
+    addField(widthField);
+    addField(heightField);
+    addField(xHotField);
+    addField(yHotField);
+    addField(typeField);
 }
 
 // Analyzer
@@ -141,6 +144,8 @@ XbmThroughAnalyzer::connectInputStream(InputStream* in) {
         }
     }
 
+    analysisResult->addValue(factory->typeField, "http://strigi.sf.net/ontologies/0.9#Cursor");
+
     return in;
 }
 
